# -*- coding utf8 -*-
'''
This package include all common function written by zhang wei(zwzw911)
'''
__all__ = ['enum','function', 'const']